@@ -30,7 +30,7 @@ class QButtonGroup;
 class QHButtonGroup;
 class QWidget;
 class DispLogic;
-class KCalcButton;
+class Constants;
 #include <kmainwindow.h>
 
 /*
@@ -56,6 +56,7 @@ class KCalcButton;
 // IMPORTANT this has to come after ../config.h
 #include "kcalc_core.h"
 #include "kcalc_button.h"
+#include "kcalc_const_button.h"
 
 class KCalculator : public KMainWindow
 {
@@ -85,8 +86,6 @@ private:
 	void keyReleaseEvent(QKeyEvent *e);
 	void set_precision();
 	void set_style();
-	void history_next();
-	void history_prev();
 	void resetBase(void) { (BaseChooseGroup->find(1))->animateClick();};
 
 	void UpdateDisplay(bool get_amount_from_core = false,
@@ -98,7 +97,6 @@ protected slots:
     void set_colors();
     void EnterEqual();
     void showSettings();
-    void RefreshCalculator();
     void slotStatshow(bool toggled);
     void slotTrigshow(bool toggled);
     void slotExpLogshow(bool toggled);
@@ -110,12 +108,12 @@ protected slots:
     void slotBaseSelected(int number);
     void slotNumberclicked(int number_clicked);
     void slotEEclicked(void);
-    void slotPiclicked(void);
     void slotInvtoggled(bool myboolean);
-    void slotMRclicked(void);
+    void slotMemRecallclicked(void);
+    void slotMemStoreclicked(void);
     void slotSinclicked(void);
     void slotPlusMinusclicked(void);
-    void slotMPlusMinusclicked(void);
+    void slotMemPlusMinusclicked(void);
     void slotCosclicked(void);
     void slotReciclicked(void);
     void slotTanclicked(void);
@@ -141,6 +139,7 @@ protected slots:
     void slotPeriodclicked(void);
     void slotEqualclicked(void);
     void slotPercentclicked(void);
+    void slotRootclicked(void);
     void slotNegateclicked(void);
     void slotModclicked(void);
     void slotStatNumclicked(void);
@@ -150,21 +149,29 @@ protected slots:
     void slotStatDataInputclicked(void);
     void slotStatClearDataclicked(void);
     void slotHyptoggled(bool flag);
-    void slotC1clicked(void);
-    void slotC2clicked(void);
-    void slotC3clicked(void);
-    void slotC4clicked(void);
-    void slotC5clicked(void);
-    void slotC6clicked(void);
-	
+    void slotConstclicked(int);
+
+    void slotConstantToDisplay(int constant);
+    void slotChooseScientificConst0(int option);
+    void slotChooseScientificConst1(int option);
+    void slotChooseScientificConst2(int option);
+    void slotChooseScientificConst3(int option);
+    void slotChooseScientificConst4(int option);
+    void slotChooseScientificConst5(int option);
+
 private:
 	bool inverse;
 	bool hyp_mode;
 	CALCAMNT memory_num;
 	CALCAMNT setvalue;
 
-public:
-	static const CALCAMNT pi;
+	// angle modes for trigonometric values
+	enum {
+	  DegMode,
+	  RadMode,
+	  GradMode
+	} _angle_mode;
+
 
 private:
     QWidget *mSmallPage;
@@ -172,21 +179,15 @@ private:
     QWidget *mNumericPage;
 
     DispLogic*	calc_display; // for historic reasons in "dlabel.h"
-    QRadioButton*        pbBaseChoose[4];
-    QPushButton*        pbAngleChoose;
-    QDict<KCalcButton>  pbStat;
-    QDict<KCalcButton>  pbTrig;
-    QDict<KCalcButton>  pbExp;
-    QDict<KCalcButton>  pbLogic;
-    QDict<KCalcButton>  pbConstant;
+    QRadioButton*	pbBaseChoose[4];
+    QPushButton*	pbAngleChoose;
+    QDict<KCalcButton>	pbStat;
+    QDict<KCalcButton>	pbTrig;
+    QDict<KCalcButton>	pbExp;
+    QDict<KCalcButton>	pbLogic;
+    KCalcConstButton*	pbConstant[10];
     KCalcButton* 	pbAC;
     KCalcButton* 	pbAND;
-    KCalcButton* 	pbC1; 
-    KCalcButton* 	pbC2; 		
-    KCalcButton* 	pbC3; 
-    KCalcButton* 	pbC4; 	
-    KCalcButton* 	pbC5; 
-    KCalcButton* 	pbC6;
     KCalcButton* 	pbClear;
     KCalcButton* 	pbDivision;
     KCalcButton* 	pbEE;
@@ -196,25 +197,32 @@ private:
     KCalcButton* 	pbMC;
     KCalcButton* 	pbMinus;
     KCalcButton* 	pbMod;
-    KCalcButton* 	pbMPlusMinus;
-    KCalcButton* 	pbMR;
+    KCalcButton* 	pbMemPlusMinus;
+    KCalcButton* 	pbMemRecall;
+    KCalcButton*	pbMemStore;
     KCalcButton* 	pbOR;
     KCalcButton* 	pbParenClose;
     KCalcButton* 	pbParenOpen;
     KCalcButton* 	pbPercent;
     KCalcButton* 	pbPeriod;
-    KCalcButton* 	pbPi;
     KCalcButton* 	pbPlus;
     KCalcButton* 	pbPlusMinus;
     KCalcButton* 	pbPower;
     KCalcButton* 	pbReci;
-    KSquareButton* 	pbSquare;
+    KSquareButton* 	pbRoot;
+    KCalcButton* 	pbSquare;
     KCalcButton* 	pbX;
     KCalcButton* 	pbXOR;
+
+    Constants * tmp_const; // this is the dialog for configuring const
+			   // buttons would like to remove this, but
+			   // don't know how
 	
     QHButtonGroup*      BaseChooseGroup;
     // NumButtonGroup: 0-9 = digits, 0xA-0xF = hex-keys
     QButtonGroup* 	NumButtonGroup;
+    // ConstButtonGroup C1-C6
+    QButtonGroup*	ConstButtonGroup;
 
     KToggleAction *actionStatshow;
     KToggleAction *actionTrigshow;
@@ -226,7 +234,6 @@ private:
     QPtrList<KCalcButton> mStatButtonList;
     QPtrList<KCalcButton> mMemButtonList;
     QPtrList<KCalcButton> mOperationButtonList;
-    QPtrList<KCalcButton> mConstButtonList;
 
     int				mInternalSpacing;
 
