@@ -1,6 +1,6 @@
 /*
 
-    $Id: kedit.h,v 1.73 2003/12/08 19:56:51 mueller Exp $
+    $Id$
 
     Copyright (C) 1997 Bernd Johannes Wuebben
                        wuebben@math.cornell.edu
@@ -199,10 +199,8 @@ private slots:
     void updateSettings();
     void readSettings();
     void showSettings();
-    void editKeys();
-    void editToolbars();
     void slotSelectionChanged();
-    void slotNewToolbarConfig();
+    QString replaceISpell(QString msg, int client);
 };
 
 class SettingsDialog: public KConfigDialog {
