@@ -35,7 +35,6 @@
 #include <ktoolbarbutton.h>
 #include <kdebug.h>
 #include <kurldrag.h>
-#include <kkeydialog.h>
 
 #include "dialog.h"
 #include "draglabel.h"
@@ -111,8 +110,8 @@ KHexEdit::KHexEdit( void )
   // Open files if this is the first toplevel window.
   //
   readConfiguration();
-  setStartupGeometry();
   initialize( mWindowList.count() == 1 ? true : false );
+  setAutoSaveSettings();
 }
 
 
@@ -127,8 +126,9 @@ void KHexEdit::setupActions( void )
 {
   KStdAction::openNew( editor(), SLOT(newFile()), actionCollection() );
   KStdAction::open( editor(), SLOT(open()), actionCollection() );
-  KStdAction::keyBindings( this, SLOT( slotConfigureKeys() ), actionCollection() );
-
+  KStdAction::keyBindings(guiFactory(), SLOT(configureShortcuts()), 
+actionCollection());
+   
   mAction.insert     = new KAction( i18n("&Insert..."), CTRL+Key_I,
     editor(), SLOT(insertFile()), actionCollection(), "insert_file" );
   mAction.openRecent = KStdAction::openRecent(0, 0, actionCollection() );
@@ -313,12 +313,6 @@ void KHexEdit::setupActions( void )
 }
 
 
-void KHexEdit::slotConfigureKeys()
-{
-  KKeyDialog::configure( actionCollection(), this );
-}
-
-
 void KHexEdit::setupStatusBar( void )
 {
   CStatusBarProgress *progess = new CStatusBarProgress( statusBar() );
@@ -779,8 +773,6 @@ void KHexEdit::writeConfiguration( KConfig &config )
 {
     saveMainWindowSettings(& config, "General Options");
   config.setGroup("General Options" );
-  config.writeEntry("Width", width() );
-  config.writeEntry("Height", height() );
   config.writeEntry("ShowFullPath",  mShowFullPath );
   config.writeEntry("ConversionPosition", (int)mManager->conversionPosition());
   config.writeEntry("TabBarPosition", (int)mManager->tabBarPosition());
@@ -871,24 +863,6 @@ void KHexEdit::readConfiguration( KConfig &config )
 
 
 
-void KHexEdit::setStartupGeometry( void )
-{
-  KConfig &config = *kapp->config();
-  config.setGroup("General Options");
-  int w = config.readNumEntry( "Width", -1 );
-  int h = config.readNumEntry( "Height", -1 );
-  if( w < 10 || h < 10 )
-  {
-    setGeometry( 0, 0, mManager->preferredWidth(), 500 );
-  }
-  else
-  {
-    setGeometry( 0, 0, w, h );
-  }
-}
-
-
-
 void KHexEdit::operationChanged( bool state )
 {
   mAction.cancel->setEnabled( state );
@@ -1511,7 +1485,7 @@ void KHexEdit::resizeTest()
   gettimeofday( &t2, 0 );
   uint last = (t2.tv_sec-t1.tv_sec) * 1000000 + (t2.tv_usec - t1.tv_usec);
 
-  kdDebug() << "Duration: " << (float)last/ 1000000.0 <<  endl;
-  kdDebug() << "Duration/loop: " << (float)last/ (1000000.0*(float)loop) << endl;
+  kdDebug(1501) << "Duration: " << (float)last/ 1000000.0 <<  endl;
+  kdDebug(1501) << "Duration/loop: " << (float)last/ (1000000.0*(float)loop) << endl;
 }
 #include "toplevel.moc"
