@@ -14,26 +14,27 @@
  *
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
- *  Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  */
 
 #ifndef KSIM__LED_H
 #define KSIM__LED_H
 
 #include "progress.h"
+#include <kdemacros.h>
 #include <qpixmap.h>
 
 namespace KSim
 {
   /**
    * A custom led for use with KSim::LedLabel,
-   * usually you shouldnt need to use this class, use KSim::LedLabel instead
+   * usually you shouldn't need to use this class, use KSim::LedLabel instead
    * @see KSim::LedLabel
    *
    * @short led using gkrellm themes
    * @author Robbie Ward <linuxphreak@gmx.co.uk>
    */
-  class Led : public QPixmap
+  class KDE_EXPORT Led : public QPixmap
   {
     public:
       enum Type { First = 0, Second };
@@ -44,7 +45,7 @@ namespace KSim
        * @param type is the led type
        * @param ImageName is the image to display
        * the image's height is divided by 4 and each item is used for send in,
-       * send out, recieve in and recieve out
+       * send out, receive in and receive out
        * @param parent is the parent widget
        * @param name is the object instance name
        */
@@ -79,7 +80,7 @@ namespace KSim
        */
       bool isOn() const;
       /**
-       * sets the type of led, send or recieve
+       * sets the type of led, send or receive
        */
       void setType(Type type);
       /**
@@ -103,7 +104,7 @@ namespace KSim
    * @short Label widget with 2 leds
    * @author Robbie Ward <linuxphreak@gmx.co.uk>
    */
-  class LedLabel : public KSim::Progress
+  class KDE_EXPORT LedLabel : public KSim::Progress
   {
     Q_OBJECT
     public:
